'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a61d733f.js');
const utils = require('./utils-ea4b6a17.js');
const dataTestIds_enum = require('./dataTestIds.enum-97d349ab.js');
const signTransactionsModalStore = require('./signTransactionsModalStore-8a04694e.js');

const signTransactionComponentCss = "* {\n  margin: 0;\n  padding: 0;\n  box-sizing: border-box;\n}\n\n.transaction-container {\n  display: flex;\n  flex-direction: column;\n  padding: 0rem 1rem 0rem 1rem;\n  gap: 1rem;\n}\n\n.receiver-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.data-content-container {\n  display: block;\n  width: 100%;\n  min-height: 100px;\n  height: 100px;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n  padding: 8px;\n  overflow-y: auto;\n  font-family: inherit;\n  font-size: inherit;\n  background-color: #f9f9f9;\n  white-space: pre-wrap;\n  word-wrap: break-word;\n  color: #333;\n}\n\n.data-content {\n  opacity: 0.6;\n}\n\n.fee-container {\n  display: flex;\n  flex-direction: column;\n  align-items: flex-start;\n  gap: 4px;\n  line-height: 1;\n}\n\n.sign-button-container {\n  display: flex;\n  flex-direction: column;\n}\n\n.sign-back-button {\n  display: inline-block;\n  padding: 8px 12px;\n  background-color: transparent;\n  color: #1a56db;\n  border: none;\n  border-radius: 4px;\n  cursor: pointer;\n  text-decoration: none;\n  font-size: 16px;\n\n  &:hover {\n    text-decoration: underline;\n    color: #0033a0;\n  }\n\n  &:active {\n    color: #001f70;\n  }\n\n  &:disabled {\n    color: #a1a1a1;\n    cursor: not-allowed;\n    text-decoration: none;\n    opacity: 0.6;\n  }\n}\n\n.sign-button {\n  display: block;\n  width: 200px;\n  margin: 0 auto;\n  padding: 12px;\n  background-color: #1a56db;\n  color: white;\n  border: none;\n  border-radius: 8px;\n  cursor: pointer;\n\n  &:disabled {\n    background-color: #a1a1a1;\n    color: #e0e0e0;\n    cursor: not-allowed;\n    opacity: 0.6;\n    box-shadow: none;\n    transform: none;\n  }\n}\n\n.highlight {\n  opacity: 1;\n}\n";
const SignTransactionComponentStyle0 = signTransactionComponentCss;

var __rest = (undefined && undefined.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
const SignTransaction = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
    }
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = signTransactionsModalStore.state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: signTransactionsModalStore.state.isWaitingForSignature,
                'data-testid': dataTestIds_enum.DataTestIdsEnum.signTransactionBtn,
                onClick: signTransactionsModalStore.state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': dataTestIds_enum.DataTestIdsEnum.signNextTransactionBtn,
            onClick: signTransactionsModalStore.state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = signTransactionsModalStore.state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': dataTestIds_enum.DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: signTransactionsModalStore.state.onCancel
            };
        }
        return {
            'data-testid': dataTestIds_enum.DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: signTransactionsModalStore.state.onPrev,
            disabled: signTransactionsModalStore.state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = signTransactionsModalStore.state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (index.h("span", null, parts.map((part, index$1) => (index.h("span", null, index.h("span", { class: "data-content" }, part), index$1 < parts.length - 1 && (index.h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = signTransactionsModalStore.state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (index.h("div", { key: '85c6e8a31efb66817aabcd3c75b8134abcf14e41', class: "transaction-container" }, this.header, index.h("div", { key: 'a905c0a64ebca05482d5ca4911e573597eb77969', class: "receiver-container" }, index.h("p", { key: '097dfec301557b497c4b7635581c99093835385a' }, "To"), index.h("p", { key: 'db17812145b10909f805bb0f9d16d51dabd380ec' }, utils.formatAddress(receiver, 40))), index.h("div", { key: '551f31625eeca1fa5d3865908adf1ff0da513fcb', class: "fee-container" }, index.h("p", { key: 'cb9ee7c9ec62fdecb0f529a4327f720d13e6689e' }, "Transaction fee"), feeLimit && (index.h("p", { key: '9243699453ca63211555931ca0c49a9afbbbab67' }, index.h("span", { key: '2ba3cf9dd524398f5b719921e87e4b6e4ca32643' }, feeLimit), "\u00A0", index.h("span", { key: '920ac7d915b4af5f8450ae43e261eb2cc1f84eb7' }, egldLabel))), index.h("p", { key: '532074a07717ffbeb03323d37f0c8efa5c0bec07' }, "\u2248", feeInFiatLimit)), scCall && (index.h("div", { key: 'b0a5445c6cbb147fb40d6ebec15707dbd4bcce73', class: "data-container" }, index.h("p", { key: '7a1da709e03ff92f6e6c9d4c995d4ac7ee430142' }, "Smart Contract Call"), index.h("div", { key: 'bb33091d251009b57986632e18244d7461f2f2bd', class: "data-content-container" }, scCall))), index.h("div", { key: '67ef02c7da9686b290ef8194857ec4bb155efbc1', class: "data-container" }, index.h("p", { key: '92b79942b35a9e6224c95c0b955505a49cc67b00' }, "Data"), index.h("div", { key: 'a8e9c462ce8b43bcb252c84cec9caa2c09207909', class: "data-content-container" }, highlightedData)), index.h("div", { key: '30ffd5b97ff89ae3a9734c28660876c8a96f47a2', class: "sign-button-container" }, index.h("button", Object.assign({ key: 'bf4da80054e88510197fcd50d1a163e7bd06bd74', class: "sign-button" }, signButtonProps), signText), backButtonText && (index.h("button", Object.assign({ key: '2c18d6bc90c636a086dbec68db5390bf400341ae', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
};
SignTransaction.style = SignTransactionComponentStyle0;

exports.sign_transaction_component = SignTransaction;

//# sourceMappingURL=sign-transaction-component.cjs.entry.js.map