var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { h } from "@stencil/core";
import { formatAddress } from "../../../../utils/utils";
import { DataTestIdsEnum } from "../../../../constants/dataTestIds.enum";
import state from "../../signTransactionsModalStore";
export class SignTransaction {
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: state.isWaitingForSignature,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                onClick: state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            onClick: state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: state.onCancel
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: state.onPrev,
            disabled: state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && (h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: '85c6e8a31efb66817aabcd3c75b8134abcf14e41', class: "transaction-container" }, this.header, h("div", { key: 'a905c0a64ebca05482d5ca4911e573597eb77969', class: "receiver-container" }, h("p", { key: '097dfec301557b497c4b7635581c99093835385a' }, "To"), h("p", { key: 'db17812145b10909f805bb0f9d16d51dabd380ec' }, formatAddress(receiver, 40))), h("div", { key: '551f31625eeca1fa5d3865908adf1ff0da513fcb', class: "fee-container" }, h("p", { key: 'cb9ee7c9ec62fdecb0f529a4327f720d13e6689e' }, "Transaction fee"), feeLimit && (h("p", { key: '9243699453ca63211555931ca0c49a9afbbbab67' }, h("span", { key: '2ba3cf9dd524398f5b719921e87e4b6e4ca32643' }, feeLimit), "\u00A0", h("span", { key: '920ac7d915b4af5f8450ae43e261eb2cc1f84eb7' }, egldLabel))), h("p", { key: '532074a07717ffbeb03323d37f0c8efa5c0bec07' }, "\u2248", feeInFiatLimit)), scCall && (h("div", { key: 'b0a5445c6cbb147fb40d6ebec15707dbd4bcce73', class: "data-container" }, h("p", { key: '7a1da709e03ff92f6e6c9d4c995d4ac7ee430142' }, "Smart Contract Call"), h("div", { key: 'bb33091d251009b57986632e18244d7461f2f2bd', class: "data-content-container" }, scCall))), h("div", { key: '67ef02c7da9686b290ef8194857ec4bb155efbc1', class: "data-container" }, h("p", { key: '92b79942b35a9e6224c95c0b955505a49cc67b00' }, "Data"), h("div", { key: 'a8e9c462ce8b43bcb252c84cec9caa2c09207909', class: "data-content-container" }, highlightedData)), h("div", { key: '30ffd5b97ff89ae3a9734c28660876c8a96f47a2', class: "sign-button-container" }, h("button", Object.assign({ key: 'bf4da80054e88510197fcd50d1a163e7bd06bd74', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: '2c18d6bc90c636a086dbec68db5390bf400341ae', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get is() { return "sign-transaction-component"; }
    static get originalStyleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get properties() {
        return {
            "header": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "VNode",
                    "resolved": "VNode",
                    "references": {
                        "VNode": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "node_modules::VNode"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
}
//# sourceMappingURL=sign-transaction-component.js.map
