import { r as registerInstance, c as createEvent, h, F as Fragment } from './index-1a8b9515.js';
import { g as getIconHtmlFromIconDefinition, c as classNames, f as faTimes } from './index-83fd1e89.js';
import { D as DataTestIdsEnum } from './dataTestIds.enum-a7ccf1b4.js';
import { g as getIconHtmlFromIconName } from './getIconHtmlFromIconName-720aabe5.js';

const transactionToastContentCss = ".content {\n  display: flex;\n  align-items: center;\n}\n.content-left {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  flex-direction: column;\n  padding-left: 0.5rem;\n  padding-right: 0.75rem;\n}\n.success {\n  background-color: #5cb85c;\n}\n.warning {\n  background-color: #ffc107;\n}\n.danger {\n  background-color: #d9534f;\n}\n.content-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 3rem;\n  height: 3rem;\n  border-radius: 50%;\n  svg {\n    height: auto;\n    width: 20px;\n\n    path {\n      fill: white;\n    }\n  }\n}\n\n.icon-close {\n  cursor: pointer;\n  float: right;\n  font-size: 1.5rem;\n  font-weight: 700;\n  line-height: 1;\n  color: #000;\n  text-shadow: 0 1px 0 #fff;\n  opacity: 0.5;\n  padding: 0;\n  background-color: rgba(0, 0, 0, 0);\n  border: 0;\n  display: flex;\n  align-items: center;\n  margin: 0 0.5rem;\n  width: 12px;\n}\n\n.content-right {\n  display: block;\n  overflow: hidden;\n  width: 100%;\n}\n\n.content-heading {\n  display: flex;\n  justify-content: space-between;\n  margin-bottom: 0.25rem;\n}\n\n.content-heading-title {\n  margin: 0;\n  margin-bottom: 0.5rem;\n  font-weight: 500;\n  line-height: 1.2;\n  font-size: 1.25rem;\n}\n";
const TransactionToastContentStyle0 = transactionToastContentCss;

const TransactionToastContent = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.deleteToast = createEvent(this, "deleteToast", 7);
    }
    render() {
        const { icon, iconClassName, title, hasCloseButton } = this.toastDataState;
        let iconHtml = null;
        if (typeof icon === 'string') {
            iconHtml = getIconHtmlFromIconName(icon);
        }
        if (icon instanceof HTMLElement) {
            iconHtml = icon.outerHTML;
        }
        return (h("div", { key: '24365132625772cdc90e148680420240b8990bc3', class: "content", "data-testid": DataTestIdsEnum.transactionToastContent }, h("div", { key: '45707cf74238000d29fb867a3f3094dd0ef16eac', class: "content-left" }, h("div", { key: '1b37c726419a79a7cd61990e3fd649d2bb141999', class: classNames('content-icon', iconClassName), innerHTML: iconHtml })), h("div", { key: 'f368c827e0c00ad10d32d83748a5d39a732bb94a', class: "content-right" }, h("div", { key: '7cfcdfbf844201b09bff5a57b07804aaa4385fb5', class: "content-heading" }, h("h5", { key: 'a4f99e132693565577148cd0971d3c8347d7b510', class: "content-heading-title", "data-testid": DataTestIdsEnum.transactionToastTitle }, title), hasCloseButton && h("button", { key: 'eb599222a69290d6567f77b3d0bf184d856898f0', onClick: () => this.deleteToast.emit(), type: "button", class: "icon-close", innerHTML: getIconHtmlFromIconDefinition(faTimes) })), h("div", { key: '581d7306144a66dae9f075bf580e9985cb9e2dec', class: "content-heading-title" }, h("transaction-toast-details", { key: '5659fdfe36daceb08817fe070f5cbb52aaddab83', transactions: this.transactions, processedTransactionsStatus: this.processedTransactionsStatus })))));
    }
};
TransactionToastContent.style = TransactionToastContentStyle0;

const transactionToastDetailsCss = ".status-title{font-size:0.875rem;margin:0.25rem 0 0.5rem;line-height:1.5}";
const TransactionToastDetailsStyle0 = transactionToastDetailsCss;

const TransactionDetails = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        if (this.transactions == null) {
            return null;
        }
        return (h(Fragment, null, h("div", { class: "status-title" }, this.processedTransactionsStatus), this.transactions.map(({ hash, status }) => (h("transaction-toast-details-body", { transactionClass: this.transactionClass, hash: hash, status: status, key: hash })))));
    }
};
TransactionDetails.style = TransactionToastDetailsStyle0;

const transactionToastProgressCss = ".transaction-toast-progress{position:relative}.transaction-toast-bar{position:absolute;pointer-events:none;left:-0.5rem;right:-0.5rem;bottom:-0.5rem;top:-0.5rem;background-color:gray;opacity:0.25;transition:width 0.6s ease;max-width:calc(100% + 1rem)}";
const TransactionToastProgressStyle0 = transactionToastProgressCss;

const ToastProgress = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.progressClass = 'transaction-toast-progress';
    }
    render() {
        if (!this.currentRemaining) {
            return h("slot", null);
        }
        return (h("div", { class: this.progressClass }, h("div", { class: "transaction-toast-bar", style: { width: `${this.currentRemaining}%` }, role: "progressbar", "aria-valuemin": 0, "aria-valuemax": 100, "aria-valnow": this.currentRemaining }), h("slot", null)));
    }
};
ToastProgress.style = TransactionToastProgressStyle0;

export { TransactionToastContent as transaction_toast_content, TransactionDetails as transaction_toast_details, ToastProgress as transaction_toast_progress };

//# sourceMappingURL=transaction-toast-content_3.entry.js.map